@@ -459,12 +459,7 @@ class Client(object):
                     logging.debug("Server requires 10 second timeout")
                     time.sleep(11)
                     logging.debug("Re-establishing stream . . . ")
-                    try:
-                        resp = requests.request("get", url)
-                    except requests.exceptions.ConnectionError:
-                        time.sleep(180)
-                        self.session = self._session()
-                        resp = requests.request("get", url)
+                    resp = requests.request("get", url)
                     if resp.status_code == 429:
                         logging.debug("Server requires hard timeout: 3 minute delay.")
                         time.sleep(180)
