@@ -129,7 +129,7 @@ def pipeline(
             bar = Bar(
                 f"Processing {ticker} ...", 
                 max=loop_range, 
-                suffix='%(percent)d%% Elapsed Time: %(elapsed)ds\n'
+                suffix='%(percent)d%% Elapsed Time: %(elapsed)ds'
             )
         try:
             # Start-stop intervals scaled by frequency
@@ -142,6 +142,7 @@ def pipeline(
                     ticker, begin=now, end=begin, interval=interval,
                 )
                 if df.empty: # If the server gives us no data, break to avoid error
+                    logging.info("\n")
                     logging.info("Historic data does not reach end date. Moving to next asset.")
                     break
                 else:
